<div class="row">
    <div class="col-12">
        <input type="text" id="recherche_txt" name="recherche_txt" hx-get="{% url 'retour_client:filtered_list' %}" hx-target="#liste-htmx-bug" hx-trigger="change">
    </div>
    <div class="col-3">
        <select id="statut" name="statut" hx-get="{% url 'retour_client:filtered_list' %}" hx-target="#liste-htmx-bug" hx-trigger="change">
            <option value="">Statut</option>
            {% for statut in search_statuts %}
            <option value="{{ statut.0 }}">{{ statut.1 }}</option>
            {% endfor %}
        </select>
    </div>
    <div class="col-3">
        <select id="type" name="type" hx-get="{% url 'retour_client:filtered_list' %}" hx-target="#liste-htmx-bug" hx-trigger="change">
            <option value="">Type</option>
            {% for type in search_types %}
            <option value="{{ type.0 }}">{{ type.1 }}</option>
            {% endfor %}
        </select>
    </div>
    <div class="col-3">
        <select id="utilisateur" name="utilisateur" hx-get="{% url 'retour_client:filtered_list' %}" hx-target="#liste-htmx-bug" hx-trigger="change">
            <option value="">Utilisateur</option>
            {% for user in search_users %}
            <option value="{{ user }}">{{ user }}</option>
            {% endfor %}
        </select>
    </div>
    <div class="col-3">
        <select id="priorite" name="priorite" hx-get="{% url 'retour_client:filtered_list' %}" hx-target="#liste-htmx-bug" hx-trigger="change">
            <option value="">Priorité</option>
            {% for priorite in search_priorite %}
            <option value="{{ priorite.0 }}">{{ priorite.1 }}</option>
            {% endfor %}
        </select>
    </div>
</div>
