<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Liste - Retours Clients</title>
    <meta name="robots" content="noindex, nofollow" />
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC"
          crossorigin="anonymous">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/js/bootstrap.bundle.min.js" integrity="sha384-MrcW6ZMFYlzcLA8Nl+NtUVF0sA7MsXsP1UyJoMp4YLEuNSfAP+JcXn/tWtIaxVXM"
            crossorigin="anonymous"></script>
    <script src="https://unpkg.com/htmx.org@1.5.0"></script>
    <style>{% include 'css/pipeline.css' %}</style>
</head>
<body>
<header>
    <img src="https://revolucy.fr/wp-content/uploads/2022/02/RVL_logo_quadri_horizontal_blanc.png" alt="Logo Revolucy" class="logorevo">
    <h1>Retour Client - <span style="text-transform: capitalize;">{{ environnement }}</span>{% if environnement == 'production' %} | {% if jrs_restant_garantie >= 0 %}{{ jrs_restant_garantie }} jours restants de garantie{% else %}Décompte en ticket horaire ({{ solde_ticket }}H){% endif %}{% endif %}
    </h1>
</header>
<div id="pipeline-retour-client" class="row">
    <div id="liste_des_retours" class="col-12 col-lg-4 p-4">
        <div id="listBug">
            <h4>Liste
                <a href="{% url 'retour_client:kanban_retours' %}" style="background: #050dbe;color: #FFF;text-decoration: none;padding: 4px 15px;margin-left: 5px;border: none;border-radius: 5px;">Kanban</a>
                <a href="{% url 'retour_client:cockpit' %}" style="background: #e63363;color: #FFF;text-decoration: none;padding: 4px 15px;margin-left: 5px;border: none;border-radius: 5px;">Stats</a>
                {% if user.is_admin_revo %}
                <div class="stat-type-retour">
                    <div>Bug : {{ nb_bug }}</div>
                    <div>Qst : {{ nb_question }}</div>
                    <div>MAJ : {{ nb_v1 }}</div>
                    <div>V2 : {{ nb_v2 }}</div>
                    <div>NC : {{ nb_non_classe }}</div>
                </div>
                {% endif %}
            </h4>
            <div class="recherche-filtre-bug">
                {% include "recherche-filtre-bug.html" %}
            </div>
            <div id="liste-htmx-bug">
                {% include "liste-retour-client.html" %}
            </div>
        </div>
    </div>
    <div id="affichage_des_retours" class="col-12 col-lg-8 p-0">
        {% include "detail-retour-client.html" %}
    </div>
</div>

<!-- Chatbot IA -->
{% include "chatbot-sidebar.html" %}

<script>
    document.addEventListener('click', function (event) {
        if (event.target.closest('.lienbug')) {
            document.querySelectorAll('.lienbug').forEach(function (element) {
                element.classList.remove('active');
            });
            event.target.closest('.lienbug').classList.add('active');
        }
    });
</script>

</body>
</html>