
#id_piece_jointe {
    background: #fff;
}

#detail_du_retour, #commentaires_retours {
    overflow-y: scroll !important;
    height: 100vh;
    padding-bottom: 200px !important;
}

a.lienbugliste {
    text-decoration: none;
    color: #000;
    font-weight: bold;
    margin-bottom: 10px;
    display: block;
}

div.stat-type-retour > div {
    padding: 0 7px;
    border-left: 1px solid;
}

div.stat-type-retour {
    font-size: 10px;
    display: flex;
    float: right;
    margin-top: 7px;
}

.btn.refus-correction-bug {
    background: #fb6c6c;
    color: #fff;
}

img.img-bug {
    width: auto;
    height: auto;
    max-width: 100%;
    max-height: 250px;
    margin: auto;
    display: block;
}

a.btn-v2 {
    font-size: 13px;
    background: #48cae4;
    border: 1px solid transparent;
    padding: 5px 10px;
    margin-left: 8px;
    text-decoration: none;
    color: #fff;
    border-radius: 6px;
    float: right;
    cursor: pointer;
}

a.btn-v2.active {
    border: 1px solid #000;
}

.recherche-filtre-bug select, .recherche-filtre-bug input {
    width: 100%;
    background: #fff;
    border: 2px solid #c5c5c5;
    padding: 5px 10px;
    font-size: 12px;
    border-radius: 15px;
}

.recherche-filtre-bug select {
    text-transform: uppercase;
    margin-top: 5px;
}

.recherche-filtre-bug {
    margin-bottom: 15px;
}

header {
    background: url(https://revolucy.fr/wp-content/uploads/2021/09/background-partenaires.jpg);
    background-size: cover;
    background-position: left center;
    margin: 20px;
    padding: 15px 25px;
    border-radius: 20px;
}

#pipeline-retour-client {
    margin: 20px;
    border: 3px solid #1e264a;
    border-radius: 20px;
    overflow: hidden;
    height: 85vh;
}

header h1 {
    color: #fff;
    float: right;
    margin-top: 25px;
    font-size: 22px;
    margin-bottom: 0;
    margin-right: 20px;
    line-height: 1;
}

.logorevo {
    max-width: 250px;
    display: inline-block;
}

.item-response {
    background: #e6e6e6;
    max-width: 80%;
    padding: 10px;
    font-size: 12px;
    border-radius: 20px;
    margin-top: 15px;
    color: #000;
    position: relative;
}

.item-response.repondant-client {
    margin-left: 20%;
}

.item-response.repondant-revo::after {
    content: "";
    background-color: #fff;
    width: 22px;
    height: 23px;
    right: -10px;
    position: absolute;
    background-image: url(https://revolucy.fr/wp-content/uploads/2024/12/icone-revo-retour.png);
    background-size: 70%;
    background-repeat: no-repeat;
    background-position: center;
    border-radius: 100%;
    top: 8px;
}

.item-response.repondant-revo {
    background: #e63363;
    color: #fff;
}

#liste_des_retours {
    background: #ededed;
    border-right: 2px solid #c5c5c5;
    overflow-y: scroll;
    height: 100%;
}

#commentaires_retours {
    background: #e6336317;
    border-left: 2px solid #e63363;
}

.lienbug {
    display: block;
    padding: 7px 10px;
    font-size: 15px;
    border-radius: 5px;
    margin-top: 0;
    color: #000;
    margin-bottom: 5px;
    background: #fff;
    border: 1px solid #c5c5c5;
    text-decoration: none;
    position: relative;
}

#listBug a.lienbug.active, #listBug a.lienbug:hover {
    background: #e6e6e6;
    color: #000;
    border: 1px solid #b8b8b8;
}

.lienbug.repondant-client {
    margin-left: 20%;
}

.lienbug.repondant-revo::after {
    content: "";
    background-color: #fff;
    width: 22px;
    height: 23px;
    right: -10px;
    position: absolute;
    background-image: url(https://revolucy.fr/wp-content/uploads/2024/12/icone-revo-retour.png);
    background-size: 70%;
    background-repeat: no-repeat;
    background-position: center;
    border-radius: 100%;
    top: 8px;
}

.lienbug.type_bug_N {
    background-color: #c7dbfa;
}

.lienbug.repondant-revo {
    background: #e63363;
    color: #fff;
}

table.retour_bug_table {
    font-size: 12px;
    width: 100%;
    margin-top: 10px;
}

table.retour_bug_table td {
    border: 1px solid #969696;
    padding: 5px;
}

table.retour_bug_table tr > td:first-child {
    background: #e6e6e6;
}

span.repondant {
    position: absolute;
    right: 10px;
    font-size: 20px;
}

#comment_form select, #comment_form textarea, #comment_form input {
    width: 100%;
    margin-bottom: 15px;
    border-radius: 5px;
    padding: 5px 10px;
    border: 2px solid #c5c5c5;
}

#commentaires_retours h4, #detail_du_retour h4, #listBug h4 {
    text-align: left;
    text-transform: uppercase;
    border-bottom: 1px solid;
    margin-bottom: 15px;
    padding-bottom: 15px;
    font-size: 18px;
}

#comment_form {
    margin-top: 25px;
}

#comment_form button {
    width: 100%;
    background: #e63363;
    color: #fff;
    border: none;
    padding: 5px;
    border-radius: 10px;
    text-transform: uppercase;
}

#comment_form button:hover {
    background: #000;
}

span.num_ticket {
    background: #c5c5c5;
    width: 30px;
    height: 30px;
    text-align: center;
    line-height: 30px;
    border-radius: 3px;
    margin-right: 5px;
    font-size: 12px;
    color: #fff;
    display: inline-block;
}

@media (max-width: 600px) {
    header h1 {
        display: none;
    }
}