{% for url, bugs in grouped_bugs.items %}
    <a class="lienbugliste" href="{{ url }}" target="_blank">{{ url }}</a>
    {% for bug in bugs %}
        <a href="{% url 'retour_client:item_retour' pk=bug.pk %}" class="lienbug type_bug_{{ bug.type }}" hx-get="{% url 'retour_client:item_retour' pk=bug.pk %}" hx-target="#affichage_des_retours" hx-swap="innerHTML">
            <span class="num_ticket" style="background-color: {{ bug.color_statut }}">{{ bug.pk }}</span> - {{ bug.titre }}
            <span class="repondant">
                {% if bug.attente_reponse_revolucy %}
                    <img src="https://revolucy.fr/wp-content/uploads/2024/12/icone-revo-retour.png" style="width: 20px; margin-top: -5px;">
                {% elif bug.attente_reponse_client %}
                    ⚡
                {% endif %}
            </span>
        </a>
    {% endfor %}
{% empty %}
<p style="text-align: center;">Aucun bug en cours</p>
{% endfor %}