<!DOCTYPE html><html lang="fr"><head><meta charset="UTF-8"><meta name="viewport" content="width=device-width,initial-scale=1"></head><body>Bonjour,<br><br>Voici la liste des bugs restant à traiter :<br><br><table style="width:100%"><thead style="background-color:#e63363; border: 1px solid #fff"><th style="width:10%;text-align:center;color:#fff;padding:8px 15px">Num</th><th style="text-align:left;color:#fff;padding:8px 15px">Description</th><th style="width:20%;text-align:center;color:#fff;padding:8px 15px">Statut</th><th style="width:30%;text-align:center;color:#fff;padding:8px 15px">Lien</th></thead>{% for bug in bugs %}<tr style="border: 1px solid #fff"><td style="text-align:center;padding:8px 15px">{{ bug.pk }}</td><td style="text-align:left;padding:8px 15px">{{ bug.titre }}</td><td style="text-align:center;color:{{ bug.color_statut }};">{{ bug.get_statut_display }}</td><td style="text-align:center;padding:8px 15px">{{ bug.lien_url }}</td></tr>{% endfor %}</table></body></html>