.kanban-card .edit-btn {
    float: right;
    font-size: 14px;
    text-decoration: none;
    color: #000;
}

span.icone_type {
    float: right;
}

span.icone_type {
    float: right;
    margin-left: 8px;
    margin-top: 3px;
}

.icone_type i {
    font-size: 16px;
}

div.stat-type-retour > div {
    padding: 0 7px;
    border-left: 1px solid;
}

.kanban-dropzone {
    min-height: 200px;
    padding: 10px;
    background-color: #f1f1f1;
    border-radius: 8px;
    border: 2px dashed transparent;
    transition: background-color 0.2s, border-color 0.2s;
}

.kanban-dropzone.dragover {
    background-color: #e0f7fa;
    border-color: #00bcd4;
}


.kanban-column {
    background: #f8f9fa;
    border: 1px solid #dee2e6;
    border-radius: 10px;
    padding: 10px;
    max-height: 70vh;
    overflow-y: auto;
}

.kanban-title {
    font-size: 16px;
    font-weight: bold;
    margin-bottom: 10px;
    text-transform: uppercase;
    color: #1e264a;
}

.kanban-list {
    display: flex;
    flex-direction: column;
    gap: 10px;
}

.kanban-card {
    background: #fff;
    padding: 10px;
    border-radius: 6px;
    box-shadow: 0 0 5px rgba(0, 0, 0, 0.1);
    font-size: 12px;
}

.kanban-card.empty {
    background: #eee;
    text-align: center;
    font-style: italic;
}


a.btn-v2 {
    font-size: 13px;
    background: #48cae4;
    border: 1px solid transparent;
    padding: 5px 10px;
    margin-left: 8px;
    text-decoration: none;
    color: #fff;
    border-radius: 6px;
    float: right;
    cursor: pointer;
}

a.btn-v2.active {
    border: 1px solid #000;
}

.recherche-filtre-bug select, .recherche-filtre-bug input {
    width: 100%;
    background: #fff;
    border: 2px solid #c5c5c5;
    padding: 5px 10px;
    font-size: 12px;
    border-radius: 15px;
}

.recherche-filtre-bug select {
    text-transform: uppercase;
    margin-top: 5px;
}

header {
    background: url(https://revolucy.fr/wp-content/uploads/2021/09/background-partenaires.jpg);
    background-size: cover;
    background-position: left center;
    margin: 20px;
    padding: 15px 25px;
    border-radius: 20px;
}

#pipeline-retour-client {
    margin: 20px;
    border: 3px solid #1e264a;
    border-radius: 20px;
    overflow: hidden;
    height: 85vh;
}

header h1 {
    color: #fff;
    float: right;
    margin-top: 25px;
    font-size: 22px;
    margin-bottom: 0;
    margin-right: 20px;
    line-height: 1;
}

.logorevo {
    max-width: 250px;
    display: inline-block;
}

span.repondant {
    position: absolute;
    right: 10px;
    font-size: 20px;
}

#comment_form select, #comment_form textarea, #comment_form input {
    width: 100%;
    margin-bottom: 15px;
    border-radius: 5px;
    padding: 5px 10px;
    border: 2px solid #c5c5c5;
}

#commentaires_retours h4, #detail_du_retour h4, #listBug h4 {
    text-align: left;
    text-transform: uppercase;
    border-bottom: 1px solid;
    margin-bottom: 15px;
    padding-bottom: 15px;
    font-size: 18px;
}

#comment_form button {
    width: 100%;
    background: #e63363;
    color: #fff;
    border: none;
    padding: 5px;
    border-radius: 10px;
    text-transform: uppercase;
}

#comment_form button:hover {
    background: #000;
}

.modal-dialog.modal-xxl {
    min-width: 90%;
}

@media (max-width: 600px) {
    header h1 {
        display: none;
    }
}